#ifndef SITELIST_H
#define SITELIST_H

#include <fstream>
#include <iostream>
#include <list>
#include <string>
#include "Website.h"

class SiteList
{
	public:
		SiteList(): itsList() {}
		SiteList(const SiteList &rhs): itsList(rhs.GetList()) {}
		SiteList(int value): itsList(value) {}
		// class methods
		void ClearAll();
		void Edit();
		void Input();
		int Iterate() const;
		void Load(char*);
		bool NameExists(char*);
		void Remove();
		void Save(char*);
		void Search();
		void ShowList() const;
		// static methods
		static void ConvertDateFormat(char*);
		// accessors
		std::list<Website> GetList() const { return itsList; }
		// error classes
		class DuplicateName
		{
			public:
				DuplicateName(std::string name): itsName(name) {}
				void PrintError() const 
				{ std::cout << "\n\nError: \"" << itsName << "\" already exists. Please enter " \
					"a different name." << std::endl; }
			private:
				std::string itsName;
		};
		class BadFileRead
		{
			public:
				BadFileRead(std::string filename): itsFile(filename) {}
				void PrintError() const 
				{ std::cout << "\n\nError: problem reading file \"" << itsFile << "\"." << std::endl; }
			private:
				std::string itsFile;
		};
		class OutOfBounds
		{
			public:
				OutOfBounds(int max): itsMax(max) {}
				void PrintError() const 
				{ std::cout << "\n\nError: The number you entered was either too high or negative. " \
					"Please enter a number between 1 and " << itsMax << "." << std::endl; }
			private:
				int itsMax;
		};
		private:
			std::list<Website> itsList;
};

#endif